/* rawss7.h
 *
 * $Id$
 *
 * Ethereal - Network traffic analyzer
 * By Gerald Combs <gerald@ethereal.com>
 * Copyright 1998 Gerald Combs
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

#ifndef __RAWSS7_H__
#define __RAWSS7_H__

typedef struct _rawss7_hdr {
	/* NOTE: These are in network-byte order. */
	guint32 type;	/* A LINKTYPE_RAWSS7_ from tcpdump.org */
	guint16 length;
	guint16 spare;
} rawss7_hdr;

/* Maximum size of any Raw SS7 data */
#define RAWSS7_MAXLENGTH 65535

#define RAWSS7_TYPE_OFFSET 0
#define RAWSS7_TYPE_LENGTH 4
#define RAWSS7_LENGTH_OFFSET RAWSS7_TYPE_LENGTH
#define RAWSS7_LENGTH_LENGTH 2
#define RAWSS7_SPARE_OFFSET RAWSS7_LENGTH_OFFSET + RAWSS7_LENGTH_LENGTH
#define RAWSS7_SPARE_LENGTH 2

#define RAWSS7_HEADER_SIZE 8
#define RAWSS7_DATA_OFFSET RAWSS7_HEADER_SIZE


/*  For those applications that can't include "wtap.h" for whatever
 *  reason...
 */
#if !defined(WTAP_ENCAP_RAWSS7)
#define WTAP_ENCAP_RAWSS7 39
#endif

/* Allocated by tcpdump.org */
#define LINKTYPE_RAWSS7	139

/*  This is the list of protocols understood by rawss7.
 *  These values:
 *	- are allocated by tcpdump-workers[AT]tcpdump.org ("libpcap/savefile.c")
 *	- are copied here
 *	- have a 'value_string' entry in "packet-rawss7.c"
 *
 *  If you want to allocate a new number you must first ask tcpdump-workers
 *  for a new LINKTYPE_ and then make sure the value gets propogated as
 *  listed above.
 */
#define LINKTYPE_RAWSS7_MTP2	140
#define LINKTYPE_RAWSS7_MTP3	141
#define LINKTYPE_RAWSS7_SCCP	142


#endif
